<?php 

class controller_component_core_catalog extends component {
	
	protected $products_per_page = 10; // todo: добавить в конфиг каталога
	
	public function action_index() {
		return $this->action_categories();
	}
	
	public function action_categories() {
		$this->data['success'] = array();
		$this->data['notices'] = array();
		$this->data['errors'] = array();
		
		$this->data['component'] = $this->url['component'];
		$this->data['page_name'] = 'Каталог';
		
		$data = array(
			'parent_id' => 0,
			'count_products' => true,
			'order' => 'c.sort ASC',
		);
		$this->data['categories'] = $this->model->get_categories($data);
		
		foreach($this->data['categories'] as &$category) {
			$category['full_url'] = SITE_URL . $this->model->get_category_url($category['id']);
		}
		
		$page['title'] = 'Каталог';
		$page['keywords'] = 'Каталог';
		$page['description'] = 'Каталог';
		$page['html'] = $this->load_view('index');
		
		return $page;
		
	}
	
	public function action_products() {
		$this->data['success'] = array();
		$this->data['notices'] = array();
		$this->data['errors'] = array();
		
		$this->data['component'] = $this->url['component'];
		$this->data['page_name'] = 'Товары';
		
		$data = array();
		
		$this->load_helper('pagination');
		
		if(isset($this->url['params']['page'])) {
			$page = (int)$this->url['params']['page'];
		} else {
			$page = 1;
		}
		
		if(isset($this->url['params']['category_id'])) {
			$data['category_id'] = $this->data['category_id'] = (int)$this->url['params']['category_id'];
			$total_products = $this->model->get_total_products($data['category_id']);
			if($total_products) {
				$start = ($page - 1) * $this->products_per_page;
				$end = $page * $this->products_per_page;
				$data['limit'] = $start . ', ' . $end;
			}
			
			$this->helper_pagination->total = $total_products;
			$this->helper_pagination->url = SITE_URL . '/admin/' . $this->data['component'] . '/products/category_id=' . $data['category_id'] . '/page={page}';
		
		} else {
			$this->helper_pagination->total = $this->model->get_total_products();
			$this->helper_pagination->url = SITE_URL . '/admin/' . $this->data['component'] . '/products/page={page}';
		}
		
		$this->helper_pagination->limit = $this->products_per_page;
		$this->helper_pagination->page = $page;
		$this->data['pagination'] = $this->helper_pagination->render();
		
		$data['order'] = 'sort ASC, date_add ASC';

		$this->data['products'] = $this->model->get_products($data);
		$this->data['categories'] = $this->model->get_categories_list(0);
		$this->data['text_no_products'] = 'Нет товаров';
		
		$page = array();
		$page['title'] = 'Каталог';
		$page['keywords'] = 'Каталог';
		$page['description'] = 'Каталог';
		$page['html'] = $this->load_view('products');
		
		return $page;
	}
	
	public function action_add_category() {
	
		$this->data['success'] = array();
		$this->data['notices'] = array();
		$this->data['errors'] = array();
		
		$this->data['component'] = $this->url['component'];
		$this->data['page_name'] = 'Добавление категории';
		
		if(isset($_POST['name'])){
			$this->data['name'] = $_POST['name'];
			if(empty($this->data['name'])){
				$this->data['errors'][] = 'Не указано название категории';
			}
		} else {
			$this->data['name'] = '';
		}
		
		if(isset($_POST['text'])){
			$this->data['text'] = $_POST['text'];
		} else {
			$this->data['text'] = '';
		}
				
		if(isset($_POST['title']) && !empty($_POST['title'])){
			$this->data['title'] = $_POST['title'];
		} else {
			$this->data['title'] = $this->data['name'];
		}
						
		if(isset($_POST['keywords']) && !empty($_POST['keywords'])){
			$this->data['keywords'] = $_POST['keywords'];
		} else {
			$this->data['keywords'] = $this->data['name'];
		}
								
		if(isset($_POST['description']) && !empty($_POST['description'])){
			$this->data['description'] = $_POST['description'];
		} else {
			$this->data['description'] = $this->data['name'];
		}
										
		if(isset($_POST['url']) && !empty($_POST['url'])){
			$this->data['url'] = $this->str2url($_POST['url']);
		} elseif(isset($_POST['url']) && empty($_POST['url'])) {
			$this->data['url'] = $this->str2url($this->data['name']);
		} else {
			$this->data['url'] = '';
		}
		
		if(isset($_POST['parent_id'])) {
			$this->data['parent_id'] = $_POST['parent_id'];
		} elseif(isset($this->url['params']['parent_id'])) {
			$this->data['parent_id'] = $this->url['params']['parent_id'];
		} else {
			$this->data['parent_id'] = 0;
		}
			
		if(isset($_POST['sort'])){
			$this->data['sort'] = $_POST['sort'];
		} else {
			$this->data['sort'] = 1;
		}
		
		if(isset($_POST['submit_category']) && !$this->data['errors']){
			$this->data['date_add'] = time();
			
			$year = date('Y', $this->data['date_add']);
			$month = date('m', $this->data['date_add']);
			
			if(!is_dir(ROOT_DIR . '/uploads/images/catalog/' . $year)) {
				mkdir(ROOT_DIR . '/uploads/images/catalog/' . $year);
			}
			$upload_dir = ROOT_DIR . '/uploads/images/catalog/' . $year . '/' . $month;
			
			if(!is_dir($upload_dir)) {
				mkdir($upload_dir);
				mkdir($upload_dir . '/mini');
			}

			if(is_uploaded_file($_FILES['image']['tmp_name'])) {
				$this->load_helper('image');
				$this->data['image'] = $this->helper_image->img_upload('image', 800, $upload_dir . '/', 290, 170, 600);
			} else {
				$this->data['image'] = '';
			}
			
			$this->model->add_category($this->data);

			$redirect = SITE_URL . '/admin/' . $this->data['component'] . '/categories/success=added';
			$this->redirect($redirect);
		}
		
		$this->data['categories'] = $this->model->get_categories_list();
		$this->data['text_submit'] = 'Добавить';
		
		$page = array();
		$page['title'] = 'Добавление категории';
		$page['keywords'] = 'Добавление категории';
		$page['description'] = 'Добавление категории';
		$page['html'] = $this->load_view('category_form');
		
		return $page;
	}	
	
	public function action_edit_category() {

		$this->data = $this->model->get_category($this->url['actions'][1]);
		
		$this->data['success'] = array();
		$this->data['notices'] = array();
		$this->data['errors'] = array();
		
		$this->data['component'] = $this->url['component'];
		$this->data['page_name'] = 'Редактирование категории';
		
		if(isset($_POST['name'])){
			$this->data['name'] = $_POST['name'];
			if(empty($this->data['name'])){
				$this->data['errors'][] = 'Не указано название категории';
			}
		}
		
		if(isset($_POST['text'])){
			$this->data['text'] = $_POST['text'];
		}
				
		if(isset($_POST['title']) && !empty($_POST['title'])){
			$this->data['title'] = $_POST['title'];
		}
						
		if(isset($_POST['keywords']) && !empty($_POST['keywords'])){
			$this->data['keywords'] = $_POST['keywords'];
		}
								
		if(isset($_POST['description']) && !empty($_POST['description'])){
			$this->data['description'] = $_POST['description'];
		}
										
		if(isset($_POST['url']) && !empty($_POST['url'])){
			$this->data['url'] = $this->str2url($_POST['url']);
		} elseif(isset($_POST['url']) && empty($_POST['url'])) {
			$this->data['url'] = $this->str2url($this->data['name']);
		}
		
		if(isset($_POST['parent_id'])) {
			$this->data['parent_id'] = $_POST['parent_id'];
		} elseif(isset($this->url['params']['parent_id'])) {
			$this->data['parent_id'] = $this->url['params']['parent_id'];
		}
		
		if(isset($_POST['sort'])){
			$this->data['sort'] = $_POST['sort'];
		}
		
		if(isset($_POST['submit_category']) && !$this->data['errors']){
			
			$year = date('Y', $this->data['date_add']);
			$month = date('m', $this->data['date_add']);
			
			if(!is_dir(ROOT_DIR . '/uploads/images/catalog/' . $year)) {
				mkdir(ROOT_DIR . '/uploads/images/catalog/' . $year);
			}

			$upload_dir = ROOT_DIR . '/uploads/images/catalog/' . $year . '/' . $month;
			
			if(!is_dir($upload_dir)) {
				mkdir($upload_dir);
				mkdir($upload_dir . '/mini');
			}

			if(is_uploaded_file($_FILES['image']['tmp_name'])) {
				
				@unlink($upload_dir . '/' . $this->data['image']);
				@unlink($upload_dir . '/mini/' . $this->data['image']);
				
				$this->load_helper('image');
				$this->data['image'] = $this->helper_image->img_upload('image', 800, $upload_dir . '/', 290, 170, 600);
			}
			
			$this->model->edit_category($this->data);

			$redirect = SITE_URL . '/admin/' . $this->data['component'] . '/categories/success=edited';
			$this->redirect($redirect);
		}
		
		$this->data['categories'] = $this->model->get_categories_list();
		$this->data['text_submit'] = 'Сохранить изменения';
		
		$page = array();
		$page['title'] = 'Редактирование категории';
		$page['keywords'] = 'Редактирование категории';
		$page['description'] = 'Редактирование категории';
		$page['html'] = $this->load_view('category_form');
		
		return $page;
	}
	
	public function action_delete_category() {
		$category = $this->model->get_category($this->url['actions'][1]);
		
		if(!empty($category['image'])) {
			$m = date('m', $category['date_add']);
			$y = date('Y', $category['date_add']);
			
			@unlink(ROOT_DIR . '/uploads/images/catalog/' . $y . '/' . $m . '/' . $category['image']);
			@unlink(ROOT_DIR . '/uploads/images/catalog/' . $y . '/' . $m . '/mini/' . $category['image']);
		}
		
		$this->model->delete_category($this->url['actions'][1]);
		$this->redirect(SITE_URL . '/admin/' . $this->url['component'] . '/categories/success=deleted');
	}
		
	public function action_add_product() {
	
		$this->data['success'] = array();
		$this->data['notices'] = array();
		$this->data['errors'] = array();
		
		$this->data['component'] = $this->url['component'];
		$this->data['page_name'] = 'Добавление товара';
		
		if(isset($_POST['name'])){
			$this->data['name'] = $_POST['name'];
			if(empty($this->data['name'])){
				$this->data['errors'][] = 'Не указано название товара';
			}
		} else {
			$this->data['name'] = '';
		}
		
		if(isset($_POST['text'])){
			$this->data['text'] = $_POST['text'];
		} else {
			$this->data['text'] = '';
		}
				
		if(isset($_POST['title']) && !empty($_POST['title'])){
			$this->data['title'] = $_POST['title'];
		} else {
			$this->data['title'] = $this->data['name'];
		}
						
		if(isset($_POST['keywords']) && !empty($_POST['keywords'])){
			$this->data['keywords'] = $_POST['keywords'];
		} else {
			$this->data['keywords'] = $this->data['name'];
		}
								
		if(isset($_POST['description']) && !empty($_POST['description'])){
			$this->data['description'] = $_POST['description'];
		} else {
			$this->data['description'] = $this->data['name'];
		}
										
		if(isset($_POST['url']) && !empty($_POST['url'])){
			$this->data['url'] = $this->str2url($_POST['url']);
		} elseif(isset($_POST['url']) && empty($_POST['url'])) {
			$this->data['url'] = $this->str2url($this->data['name']);
		} else {
			$this->data['url'] = '';
		}
		
		if(isset($_POST['category_id'])) {
			$this->data['category_id'] = $_POST['category_id'];
		} elseif(isset($this->url['params']['category_id'])) {
			$this->data['category_id'] = $this->url['params']['category_id'];
		} else {
			$this->data['category_id'] = 0;
		}
		
		if(isset($_POST['price'])){
			$this->data['price'] = $_POST['price'];
		} else {
			$this->data['price'] = '';
		}
				
		if(isset($_POST['special'])){
			$this->data['special'] = $_POST['special'];
		} else {
			$this->data['special'] = '';
		}
		
		if(isset($_POST['quantity'])){
			$this->data['quantity'] = $_POST['quantity'];
		} else {
			$this->data['quantity'] = 1;
		}
			
		if(isset($_POST['sort'])){
			$this->data['sort'] = $_POST['sort'];
		} else {
			$this->data['sort'] = 1;
		}
		
		if(isset($_POST['submit_product']) && !$this->data['errors']){
			$this->data['date_add'] = time();
			
			$year = date('Y', $this->data['date_add']);
			$month = date('m', $this->data['date_add']);
			
			if(!is_dir(ROOT_DIR . '/uploads/images/catalog/' . $year)) {
				mkdir(ROOT_DIR . '/uploads/images/catalog/' . $year);
			}
			$upload_dir = ROOT_DIR . '/uploads/images/catalog/' . $year . '/' . $month;
			
			if(!is_dir($upload_dir)) {
				mkdir($upload_dir);
				mkdir($upload_dir . '/mini');
			}

			if(is_uploaded_file($_FILES['image']['tmp_name'])) {
				$this->load_helper('image');
				$this->data['image'] = $this->helper_image->img_upload('image', 800, $upload_dir . '/', 290, 170, 600);
			} else {
				$this->data['image'] = '';
			}
			
			$this->model->add_product($this->data);

			$redirect = SITE_URL . '/admin/' . $this->data['component'] . '/products/success=added';
			$this->redirect($redirect);
		}
		
		$this->data['categories'] = $this->model->get_categories_list();
		$this->data['text_submit'] = 'Добавить';
		
		$page = array();
		$page['title'] = 'Добавление товара';
		$page['keywords'] = 'Добавление товара';
		$page['description'] = 'Добавление товара';
		$page['html'] = $this->load_view('product_form');
		
		return $page;
	}	
	
	public function action_edit_product() {

		$this->data = $this->model->get_product($this->url['actions'][1]);
		
		$this->data['success'] = array();
		$this->data['notices'] = array();
		$this->data['errors'] = array();
		
		$this->data['component'] = $this->url['component'];
		$this->data['page_name'] = 'Редактирование товара';
		
		if(isset($_POST['name'])){
			$this->data['name'] = $_POST['name'];
			if(empty($this->data['name'])){
				$this->data['errors'][] = 'Не указано название товара';
			}
		}
		
		if(isset($_POST['text'])){
			$this->data['text'] = $_POST['text'];
		}
				
		if(isset($_POST['title']) && !empty($_POST['title'])){
			$this->data['title'] = $_POST['title'];
		}
						
		if(isset($_POST['keywords']) && !empty($_POST['keywords'])){
			$this->data['keywords'] = $_POST['keywords'];
		}
								
		if(isset($_POST['description']) && !empty($_POST['description'])){
			$this->data['description'] = $_POST['description'];
		}
										
		if(isset($_POST['url']) && !empty($_POST['url'])){
			$this->data['url'] = $this->str2url($_POST['url']);
		} elseif(isset($_POST['url']) && empty($_POST['url'])) {
			$this->data['url'] = $this->str2url($this->data['name']);
		}
		
		if(isset($_POST['category_id'])) {
			$this->data['category_id'] = $_POST['category_id'];
		} elseif(isset($this->url['params']['category_id'])) {
			$this->data['category_id'] = $this->url['params']['category_id'];
		}
		
		if(isset($_POST['price'])){
			$this->data['price'] = $_POST['price'];
		}
				
		if(isset($_POST['special'])){
			$this->data['special'] = $_POST['special'];
		}
		
		if(isset($_POST['quantity'])){
			$this->data['quantity'] = $_POST['quantity'];
		}
			
		if(isset($_POST['sort'])){
			$this->data['sort'] = $_POST['sort'];
		}
		
		if(isset($_POST['submit_product']) && !$this->data['errors']){
			
			$year = date('Y', $this->data['date_add']);
			$month = date('m', $this->data['date_add']);
			
			if(!is_dir(ROOT_DIR . '/uploads/images/catalog/' . $year)) {
				mkdir(ROOT_DIR . '/uploads/images/catalog/' . $year);
			}

			$upload_dir = ROOT_DIR . '/uploads/images/catalog/' . $year . '/' . $month;
			
			if(!is_dir($upload_dir)) {
				mkdir($upload_dir);
				mkdir($upload_dir . '/mini');
			}

			if(is_uploaded_file($_FILES['image']['tmp_name'])) {
				
				@unlink($upload_dir . '/' . $this->data['image']);
				@unlink($upload_dir . '/mini/' . $this->data['image']);
				
				$this->load_helper('image');
				$this->data['image'] = $this->helper_image->img_upload('image', 800, $upload_dir . '/', 290, 170, 600);
			}
			
			$this->model->edit_product($this->data);

			$redirect = SITE_URL . '/admin/' . $this->data['component'] . '/products/success=edited';
			$this->redirect($redirect);
		}
		
		$this->data['categories'] = $this->model->get_categories_list();
		$this->data['text_submit'] = 'Сохранить изменения';
		
		$page = array();
		$page['title'] = 'Редактирование товара';
		$page['keywords'] = 'Редактирование товара';
		$page['description'] = 'Редактирование товара';
		$page['html'] = $this->load_view('product_form');
		
		return $page;
	}
	
	public function action_delete_product() {
		$product = $this->model->get_product($this->url['actions'][1]);
		
		if(!empty($product['image'])) {
			$m = date('m', $product['date_add']);
			$y = date('Y', $product['date_add']);
			
			@unlink(ROOT_DIR . '/uploads/images/catalog/' . $y . '/' . $m . '/' . $product['image']);
			@unlink(ROOT_DIR . '/uploads/images/catalog/' . $y . '/' . $m . '/mini/' . $product['image']);
		}
		
		$this->model->delete_product($this->url['actions'][1]);
		$this->redirect(SITE_URL . '/admin/' . $this->url['component'] . '/products/success=deleted');
	}
	
	public function action_ajax_get_children() {
	
		if(!isset($_POST['parent_id'])) {
			exit();
		}
		$this->data['parent_id'] = (int)$_POST['parent_id'];
		
		$data = array(
			'parent_id' => $this->data['parent_id'],
			'count_products' => true,
			'order' => 'c.sort ASC',
		);
		
		$this->data['categories'] = $this->model->get_categories($data);
		
		foreach($this->data['categories'] as &$category) {
			$category['full_url'] = SITE_URL . $this->model->get_category_url($category['id']);
		}
		
		$this->data['component'] = $this->url['component'];
		
		$page['theme']['file'] = 'ajax';
		$page['html'] = $this->load_view('ajax_categories_rows');
		return $page;
	}
}